;+
; NAME:
;  mag_SVD
; singular value decomposition of a magnetic spectral matrix
;  Input: SM, spectral matrix in the compact format
;  Output:
;    theta, phi: angles (deg) defining the k-vector direction
;    plan: planarity of polarization
;    el : ellipticity
;    theta_maj,phi_maj: angles (deg) defining the major polarization axis
;    theta_min,phi_min: angles (deg) defining the minor polarization axis
;  History:
;    Mar 13, 2000, OS written for PRASSADCO
;    ....
;    may, 2004, rewritten
;    jun 2007, revised
;-

pro mag_SVD,SM,theta,phi,plan,el,theta_maj,phi_maj,theta_min,phi_min
      n=sqrt(n_elements(SM))
;__svd analysis of the  SM
      A=[ [SM(0), SM(1), SM(3)], $
      [SM(1), SM(2*n-1), SM(2*n)], $
      [SM(3), SM(2*n), SM(4*n-4)], $
      [0., -SM(2), -SM(4)], $
      [ SM(2), 0., -SM(2*n+1)], $
      [ SM(4), SM(2*n+1), 0.] ]
    svdc,A,w,u,v,/double
       ie=sort(w) & w=w(ie) & v=v(ie,*) & u=u(ie,*)
       if (w(2) gt 0.) then begin
        ;__"planarity of polarization: 0 for 3d polar, 1 for 2d or 1d polar"
         plan=1.-sqrt(w(0)/w(2))
        ;__"ellipticity of polarization" with the sign of polarization sense
        if SM(2) lt 0 then el=-w(1)/w(2) $
                     else el= w(1)/w(2)
        ;__major axis of the polar ellipse
           theta_maj=atan(sqrt(v(2,0)^2+v(2,1)^2),v(2,2))/!dtor
           phi_maj=atan(v(2,1),v(2,0))/!dtor
        ;__minor axis of the polar ellipse
           theta_min=atan(sqrt(v(1,0)^2+v(1,1)^2),v(1,2))/!dtor
           phi_min=atan(v(1,1),v(1,0))/!dtor
        ;__k-vector (perp to polarization plane) direction
           theta=atan(sqrt(v(0,0)^2+v(0,1)^2),v(0,2))/!dtor
           phi=atan(v(0,1),v(0,0))/!dtor
       end else begin
          print,'      ....svdc(M) failed @ matrix #',j
     end
end
