;+
;  NAME:
;   power
;
;  DESCRIPTION:
;   calculates nonaveraged fft estimates
;   of power spectral density
;   from a waveform
;
;  USES:
;   sfft
;
;  INPUT:
;   sampling_frequency
;   waveform
;   nfft ... number of points entering into a single fft
;
;  OUTPUT:
;   fr(nf) ... array of frequencies
;   ft(nt) ... array of central time stamps for the spectra
;   fe(nt,nf) ... 2D array of fft estimates of power spectral density
;
;  HISTORY:
;   5/2004, O. Santolik, written using older programs (read_WBD)
;   6/2007, O. Santolik, revised
;-

pro power, sampling_frequency, waveform,  nfft, $
           fr, ft, fe
;
; ___frequency
  nfr=fix(nfft/2)  ;__number of frequency points
  dfr=sampling_frequency/float(nfft) ;__frequency step
  fr=(0.5+findgen(nfr))*dfr ;__array of frequencies
;
; ___time
  nin=n_elements(waveform)  ;__size of the waveform
  t=dindgen(nin)/sampling_frequency  ;__timing of the samples
  nt=long(float(nin)/float(nfft)*2.)-1  ;__number of resulting ffts - 50% overlap
;
; ___ffts
  fe=fltarr(nt,nfr) ;__array of power estimates
  ft=dblarr(nt) ;__array of time stamps
  for i=0l,nt-1 do begin ;__fft loop
    i0=round(float(i)*float(nfft)/2.) ;__first index into the waveform
    i1=i0+nfft-1 ;__last index into the waveform
    fe(i,*)=abs(sfft(waveform(i0:i1),nfft))^2 / dfr ; __power = |complex spectrum|^2
    ft(i)=(t(i1)+t(i0))/2d ; __ time stamp
  endfor
end ;__ pro power
