
;+
;  NAME:
;   power_spectrogram
;
;  DESCRIPTION:
;   calculates a power spectrogram from a waveform
;
;  USES:
;   power, sfft
;
;  INPUT:
;   sampling_frequency
;   waveform
;   nfft ... number of points entering into a single fft
;   nave ... number of averaged spectra
;
;  OUTPUT:
;   time(nt) ... array of central time stamps for the spectra
;   frequency(nf) ... array of frequencies
;   spectrogram(nt,nf) ... 2D array of power spectral density
;
;  HISTORY:
;   5/2004, O. Santolik, written using older programs (read_WBD)
;   6/2007, O. Santolik, revised
;-

pro power_spectrogram, sampling_frequency, waveform,  nfft, nave, $
                    time, frequency, spectrogram
 power, sampling_frequency, waveform,  nfft, $
           frequency, ft, fe ;__ nonaveraged power spectral density
 nt=n_elements(ft) ;__number of time points
 nf=n_elements(frequency)  ;__number of frequency points
 time=rebin(ft(0:nave*(nt/nave)-1),nt/nave) ;__ time for the spectrogram
 spectrogram=rebin(fe(0:nave*(nt/nave)-1,*),nt/nave,nf) ;__averaging
end

