;+
; NAME:
;  read_SM
; PURPOSE:
;  reading a spectral matrix
; INPUT:
;  file: SM ascii file
; OUTPUT:
;  SM,dSM: spectral matrix, error matrix
;  tit: title
;  fr: central frequency
;  dfr: frequency band
; history
;  Feb 27 2000 OS written
;-


pro read_SM,file,SM,dSM,tit,fr,dfr
  get_lun,lun
  openr,lun,file
;__reading header
  tit='' & readf,lun,tit & readf,lun,tit & readf,lun,tit & readf,lun,tit
  readf,lun,form='(40x,G12.5)',fr
  readf,lun,form='(40x,G12.5)',dfr
;__reading matrix
  leg='' & readf,lun,leg & readf,lun,leg
  n=(strlen(leg)-14)/24 +1
  SM=fltarr(n*n)
  for i=0,n-1 do begin
    na=2*(n-i)-1 & a=fltarr(na)
    ii=2*i*n-i*i
    readf,lun,a,form='(2x,'+strtrim(string(na),2)+'g12.5)'
    SM(ii:ii+na-1)=a
  endfor
;__reading error matrix
  readf,lun,leg & readf,lun,leg
  dSM=fltarr(n*n)
  for i=0,n-1 do begin
    na=2*(n-i)-1 & a=fltarr(na)
    ii=2*i*n-i*i
    readf,lun,a,form='(2x,'+strtrim(string(na),2)+'g12.5)'
    dSM(ii:ii+na-1)=a
  endfor
  close,lun
end
