
pro stokes_SVD, SM, I, Q, U, V,d,eps,e
;+
;  stokes_SVD
;  Input: SM, spectral matrix in the compact format
;  Output:
;  STOKES parameters I, Q, U, V
;  d: degree of polarization
;  eps, e: ellipticity
;  History:
;    Apr 28, 2004, JK written using mag_SVD
;    may, 2004, os, rewritten
;    jun 2007, os, revised
;-
        S=SM
        n=sqrt(n_elements(S))
;__svd analysis of the  SM
      A=[ [S(0), S(1), S(3)], $
      [S(1), S(2*n-1), S(2*n)], $
      [S(3), S(2*n), S(4*n-4)], $
      [0., -S(2), -S(4)], $
      [ S(2), 0., -S(2*n+1)], $
      [ S(4), S(2*n+1), 0.] ]
     svdc,A,w,u,v,/double
       ie=sort(w) & w=w(ie) & v=v(ie,*) & u=u(ie,*)
       if (w(2) gt 0.) then begin
          ;__transformation of rows (2nd index) of u to the system of principal axes
          ;   (colums already are in that system). Result: SM in the pr. ax. system
          x=fltarr(3,6) ; as is u
          for k=0,2 do for l=0,2 do for m=0,2 do x(l,k)=x(l,k)+w(l)*u(l,m)*v(k,m) ; re
          for k=3,5 do for l=0,2 do for m=3,5 do x(l,k)=x(l,k)+w(l)*u(l,m)*v(k-3,m-3) ; im

          I=x(2,2)+x(1,1)
         Q=(x(2,2)-x(1,1))/I
         U=2*x(2,1)/I                 ;sh b 0
         V=S(2)/abs(S(2))*2*abs(x(2,4))/I

         ;degree of polarization
         if (I ne 0.) then d=sqrt(Q^2 + U^2 + V^2) else d=0.

         ;elipticity
         if (V ne 0.) then eps=asin(V/d)/2. else eps=abs(acos(Q/d)/2.)
         e=S(2)/abs(S(2))*sqrt(x(1,1)/x(2,2))
     end else begin
          print,'      ....svdc(M) failed @ matrix #',j
     end ; err
end ;

