;+
; NAME:
;       TVImage
;
; PURPOSE:
;      Universal imaging of an array
;
; CATEGORY:
;       Image.
;
; CALLING SEQUENCE:
;     TVImage, M , Pos , MMin, MMax
;
; INPUTS:
;    M....input array of single precision elements
;    Pos..position (normal coord.)
;    MMin..min value of M, elements below will be set to (bottom) color
;    MMax..max value of M, elements above will be set to (top) color
;          NaN elements (invalid data) will be set to (invalid) color.
;
; KEYWORD PARAMETERS:
;
;     MaxXPix,MaxYPix.. input: maximum number of pixels of a scalable device
;                    in each coordinate
;                (used only if the dimension of the input matrix is larger)
;                    default value: 5000
;    Inverse.. inversion of color indices
;
;    Top..     maximum color index, default !d.n_colors-1
;    Bottom..  minimum color index , default 0
;    Invalid.. color index for NaN elements, default (bottom)
;
; PROCEDURE:
;       Scales an image and plots it, device independent.
;
; MODIFICATION HISTORY:
;      written   O.S. V/94
;      added the keywords MaxDt, Top & Inverse O.S. XII/94
;      keywords bottom and invalid added,
;      change of behaviour for elements>mmax, O.Santolik XI/99
;      MaxDt changed to MaxXPix and MaxYPix, O.S. I/2000
;      any dimensions of the input array accepted, O.S. II/2000
;-
;
pro TVImage, M, Pos, MMin, MMax, MaxXPix=MaxXPix, MaxYPix=MaxYPix,$
         Inverse=inve, Top=top,Bottom=bottom, Invalid=invalid
 ;on_error,2
 ;__keywords
 if NOT n_elements(mmin) then mmin=min(M)
 if NOT n_elements(mmax) then mmax=max(M)
 if NOT n_elements(top) then top=!d.n_colors-1
 if NOT n_elements(bottom) then bottom=0
 if NOT n_elements(invalid) then invalid=bottom
 inv =  keyword_set(inve)
 if top LE bottom then begin
    exch=bottom & bottom=top & top=exch
    inv= NOT inv
  end
 ;__scale to byte array
 i_nan=where(finite(M,/nan),n_nan)
 b=bottom+bytscl(M, Min=MMin, Max=MMax*(1.00433),top=top-bottom,/nan)
          ;od verze 5.2, drive 1.00005
 if n_nan gt 0 then b(i_nan)=invalid
 if keyword_set(inve) then b=!d.n_colors-1-b
 ;__getting a matrix at least 2x2
   sz = size(b)
   if sz(0) eq 0 then b=replicate(b,2,2) $
   else if sz(0) eq 1 then b=rebin(b,sz(1),2,/sample) $
   else if sz(0) gt 2 then begin
        b=reform(b) & sz = size(b)
        b=rebin(b,sz(1),sz(2),/sample)
    endif
   sz = size(b)
   if sz(1) le 1 then b=rebin(b,2,sz(2),/sample) & sz = size(b)
   if sz(2) le 1 then b=rebin(b,sz(1),2,/sample)
 ;__scale to the destination rectangle
 if ((!D.flags and 1L) EQ 0)  then begin
  ; ...non-scalable device (screen)
     px= round([Pos(0),Pos(2)] * !d.x_vsize)
     py= round([Pos(1),Pos(3)] * !d.y_vsize)
     sx = float(px(1)-px(0));
     sy = float(py(1)-py(0));
     if (sx GT 0) AND (sy GT 0) then $
     TV, poly_2d(b, $
        [[0,0],[sz(1)/sx,0]], [[0,sz(2)/sy], $
        [0,0]], 0, sx, sy), px(0), py(0)
   endif else begin
   ; ...scalable device (post script printer)
     if N_elements(maxxpix) EQ 0 then maxxpix=5000. $
     else if maxxpix gt 2. then maxxpix=float(maxxpix) else maxxpix=2.
     if N_elements(maxypix) EQ 0 then maxypix=5000. $
     else if maxypix gt 2. then maxypix=float(maxypix) else maxypix=2.
     ;print,'MaxDt,Sz1,Sz2',maxxpix,maxypix,sz(1),SZ(2)
     if sz(1) gt maxxpix then begin
       b= poly_2d(b,[[0,0],[sz(1)/MAXxpix,0]], $
         [[0,1.],[0,0]],0,maxxpix,sz(2) )
       sz(1)=maxxpix
    end
     if sz(2) gt maxypix then begin
       b= poly_2d(b,[[0,0],[1.,0]], $
           [[0,sz(2)/maxypix],[0,0]],0,sz(1),maxypix )
       sz(2)=maxypix
       end
     XSize=Pos(2)-Pos(0)
     YSize=Pos(3)-Pos(1)
     if (!d.x_vsize*xsize gt 1.)and(!d.y_vsize*ysize gt 1.) then $
      TV, b, $
    Pos(0), Pos(1), XSize=XSize,$
    YSize=YSize, /norm
   endelse
end
